@@ -1,5 +1,4 @@
 import logging
-import queue
 import textwrap
 
 import jupyter_client.kernelspec
@@ -12,6 +11,7 @@ from rich import print
 from rich.console import Console
 
 LOGGER = logging.getLogger("gui-executor.kernel")
+DEBUG = False
 
 
 class KernelError(Exception):
