@@ -61,7 +61,6 @@ from PyQt5.QtWidgets import QLineEdit
 from PyQt5.QtWidgets import QMainWindow
 from PyQt5.QtWidgets import QMenu
 from PyQt5.QtWidgets import QMessageBox
-from PyQt5.QtWidgets import QPlainTextEdit
 from PyQt5.QtWidgets import QPushButton
 from PyQt5.QtWidgets import QRadioButton
 from PyQt5.QtWidgets import QScrollArea
@@ -74,12 +73,10 @@ from PyQt5.QtWidgets import QVBoxLayout
 from PyQt5.QtWidgets import QWidget
 from executor import ExternalCommand
 from executor import ExternalCommandFailed
-from jupyter_client import KernelClient
 from rich.console import Console
 from rich.markup import escape
 from rich.syntax import Syntax
 from rich.text import Text
-from rich.pretty import Pretty
 
 from . import RUNNABLE_APP
 from . import RUNNABLE_KERNEL
@@ -111,8 +108,8 @@ from .utypes import TypeObject
 from .utypes import UQWidget
 
 HERE = Path(__file__).parent.resolve()
-DEBUG = True
-LOGGER = logging.getLogger('gui-executor')
+DEBUG = False
+LOGGER = logging.getLogger('gui-executor.view')
 
 
 class VLine(QFrame):
@@ -369,20 +366,20 @@ class FunctionRunnableKernel(FunctionRunnable):
 
         msg_id = client.execute(snippet, allow_stdin=True)
 
-        LOGGER.debug(f"{id(client)}: {msg_id = }")
+        DEBUG and LOGGER.debug(f"{id(client)}: {msg_id = }")
 
         while True:
             try:
                 io_msg = client.get_iopub_msg(msg_id, timeout=1.0)
 
                 if io_msg['parent_header']['msg_id'] != msg_id:
-                    LOGGER.warning(f"{id(client)}: Skipping {io_msg = }")
+                    DEBUG and LOGGER.debug(f"{id(client)}: Skipping {io_msg = }")
                     continue
 
                 io_msg_type = io_msg['msg_type']
                 io_msg_content = io_msg['content']
 
-                LOGGER.debug(f"{id(client)}: {io_msg = }")
+                DEBUG and LOGGER.debug(f"{id(client)}: {io_msg = }")
 
                 if io_msg_type == 'stream':
                     if 'text' in io_msg_content:
@@ -391,16 +388,16 @@ class FunctionRunnableKernel(FunctionRunnable):
                 elif io_msg_type == 'status':
                     if io_msg_content['execution_state'] == 'idle':
                         # self.signals.data.emit("Execution State is Idle, terminating...")
-                        LOGGER.debug(f"{id(client)}: Execution State is Idle, terminating...")
+                        DEBUG and LOGGER.debug(f"{id(client)}: Execution State is Idle, terminating...")
                         self.collect_response_payload(client, msg_id, timeout=1.0)
                         break
                     elif io_msg_content['execution_state'] == 'busy':
                         # self.signals.data.emit("Execution State is busy...")
-                        LOGGER.debug(f"{id(client)}: Execution State is busy...")
+                        DEBUG and LOGGER.debug(f"{id(client)}: Execution State is busy...")
                         continue
                     elif io_msg_content['execution_state'] == 'starting':
                         # self.signals.data.emit("Execution State is starting...")
-                        LOGGER.debug(f"{id(client)}: Execution State is starting...")
+                        DEBUG and LOGGER.debug(f"{id(client)}: Execution State is starting...")
                         continue
                 elif io_msg_type == 'display_data':
                     if 'data' in io_msg_content:
@@ -427,13 +424,13 @@ class FunctionRunnableKernel(FunctionRunnable):
                     self.signals.error.emit(RuntimeError(f"Unknown io_msg_type: {io_msg_type}"))
 
             except queue.Empty:
-                LOGGER.debug(f"{id(client)}: Catching on empty queue -----------")
+                DEBUG and LOGGER.debug(f"{id(client)}: Catching on empty queue -----------")
                 # We fall through here when no output is received from the kernel. This can mean that the kernel
                 # is waiting for input and therefore this is a good opportunity to check for stdin messages.
                 with contextlib.suppress(queue.Empty):
                     in_msg = client.get_stdin_msg(timeout=0.1)
 
-                    LOGGER.debug(f"{id(client)}: {in_msg = }")
+                    DEBUG and LOGGER.debug(f"{id(client)}: {in_msg = }")
 
                     if in_msg['msg_type'] == 'input_request':
                         prompt = in_msg['content']['prompt']
@@ -497,7 +494,7 @@ class FunctionRunnableKernel(FunctionRunnable):
         try:
             shell_msg = client.get_shell_msg(msg_id, timeout=timeout)
         except queue.Empty:
-            LOGGER.debug(f"{id(client)}: No shell message available for {timeout}s....")
+            DEBUG and LOGGER.debug(f"{id(client)}: No shell message available for {timeout}s....")
             self.signals.data.emit(
                 "[red]No result received from kernel, this might happen when kernel is interrupted.[/]")
             return
@@ -505,7 +502,7 @@ class FunctionRunnableKernel(FunctionRunnable):
         msg_type = shell_msg["msg_type"]
         msg_content = shell_msg["content"]
 
-        LOGGER.debug(f"{id(client)}: {shell_msg = }")
+        DEBUG and LOGGER.debug(f"{id(client)}: {shell_msg = }")
 
         if msg_type == "execute_reply":
             status = msg_content['status']
@@ -1147,7 +1144,7 @@ class View(QMainWindow):
         desktop_widget = QApplication.desktop()
         desktop_screen = desktop_widget.screenNumber(self)
         desktop_geometry = desktop_widget.availableGeometry(screen=desktop_screen)
-        LOGGER.info(f"{desktop_screen = }, {desktop_geometry = }")
+        LOGGER.debug(f"{desktop_screen = }, {desktop_geometry = }")
 
         # Not sure anymore why I put this line in, but it restricts the size of the main window to the size of the
         # main desktop screen, which might be smaller than e.g. an external screens that is attached.
@@ -1320,7 +1317,7 @@ class View(QMainWindow):
             self._kernel.shutdown()
 
         name = self.kernel_panel.selected_kernel
-        LOGGER.debug(f"Starting new kernel {name}...")
+        LOGGER.info(f"Starting new kernel {name}...")
         self._kernel = MyKernel(name)
         self._console_panel.append(f"New kernel '{name}' started...")
 
@@ -1498,10 +1495,10 @@ class View(QMainWindow):
         self._recurring_tasks.append(func)
 
     def the_button_was_double_clicked(self, *args, **kwargs):
-        LOGGER.info(f"The button was double clicked {args=}, {kwargs=}.")
+        DEBUG and LOGGER.debug(f"The button was double clicked {args=}, {kwargs=}.")
 
     def the_button_was_pressed(self, button: DynamicButton, panel, *args, **kwargs):
-        LOGGER.info(f"The button was pressed {button=}, {panel=}, {args=}, {kwargs=}.")
+        DEBUG and LOGGER.debug(f"The button was pressed {button=}, {panel=}, {args=}, {kwargs=}.")
 
         if button.immediate_run():
             if button.function.__ui_allow_kernel_interrupt__:
